
/*
 *
 * A set of routines to read and write integers and IEEE
 * floating-point numbers taking into account the byte order.
 *
 * Based on the C++ advanced I/O library written by Oleg Kiselyov.
 *
 * Copyright 2005-2008 Ivan Raikov and the Georgia Institute of Technology
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * A full copy of the GPL license can be found at
 * <http://www.gnu.org/licenses/>.
 *
 */

#ifndef endian_lowio_h
#define endian_lowio_h

typedef enum { MSB, LSB } byte_order_t;

// Most significant byte first
byte_order_t endian_lowio_big_endian(void)
{ 
     return MSB; 
}

// Least significant byte first
byte_order_t endian_lowio_little_endian(void)
{ 
     return LSB; 
}

// Is the given byte order MSB first?
int endian_lowio_is_MSB(byte_order_t b) 
{ 
     return (b == MSB); 
}


// Make sure the file was opened for appending successfully
int endian_lowio_assert_append(const char * file_name);


// Make sure the file was created (or truncated) successfully
int endian_lowio_assert_create(const char * file_name);


unsigned char  endian_lowio_read_int1 (int, byte_order_t);

unsigned short endian_lowio_read_int2 (int, byte_order_t);

unsigned long  endian_lowio_read_int4 (int, byte_order_t);

unsigned long  endian_lowio_read_int4 (int, byte_order_t);

unsigned long long endian_lowio_read_int8 (int, byte_order_t);

void endian_lowio_read_ieee_float32  (int, byte_order_t, int *, double *);

void endian_lowio_read_ieee_float64  (int, byte_order_t, int *, double *);



void  endian_lowio_write_int1 (int, byte_order_t, const char);

void  endian_lowio_write_int2 (int, byte_order_t, const unsigned short);

void  endian_lowio_write_int4 (int, byte_order_t, const unsigned long);

void  endian_lowio_write_int8 (int, byte_order_t, const unsigned long long);

void  endian_lowio_write_ieee_float32 (int, byte_order_t, const float);

void  endian_lowio_write_ieee_float64 (int, byte_order_t, const double);


#endif
