
/*
 *
 * SWIG interface to the endian I/O C library
 *
 * Copyright 2005-2008 Ivan Raikov and the Georgia Institute of Technology
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * A full copy of the GPL license can be found at
 * <http://www.gnu.org/licenses/>.
 *
 */

%module endian_lowio 

%{

#include <math.h>

typedef enum { MSB, LSB } byte_order_t;

extern const char* endian_lowio_error_string;
extern int endian_lowio_error_status;

void clear_exception() 
     {
	  endian_lowio_error_status = 0;
     }

const char *check_exception() 
     {
	  if (endian_lowio_error_status > 0) 
	       return endian_lowio_error_string;	      
	  else return NULL;
     }


%}

%include typemaps.i
%include exception.i

typedef enum { MSB, LSB } byte_order_t;

%exception 
{
     const char *err;
     clear_exception();
     $action
     if ((err = check_exception())) 
     {
	  SWIG_exception(SWIG_IOError, endian_lowio_error_string);
     }
}

%inline %{

// Most significant byte first
extern byte_order_t endian_lowio_big_endian(void);

// Least significant byte first
extern byte_order_t endian_lowio_little_endian(void);

// Is the given byte order MSB first?
extern int endian_lowio_is_MSB(byte_order_t b);

// Make sure the file was opened for appending successfully
extern int endian_lowio_assert_append(const char * file_name);

// Make sure the file was created (or truncated) successfully
extern int endian_lowio_assert_create(const char * file_name);


extern unsigned int  endian_lowio_read_int1 (int, byte_order_t);

extern unsigned short endian_lowio_read_int2 (int, byte_order_t);

extern unsigned long  endian_lowio_read_int4 (int, byte_order_t);

extern unsigned long  endian_lowio_read_int4 (int, byte_order_t);

extern unsigned long long endian_lowio_read_int8 (int, byte_order_t);

%}



%typemap(in,numinputs=0) int *nan (int temp) {
   $1 = &temp;
}

#ifdef SWIGCHICKEN
%typemap(argout) (int *nan) {
	SWIG_APPEND_VALUE(C_mk_bool (*$1));
}
#endif

%inline %{

extern void endian_lowio_read_ieee_float32  (int fd, byte_order_t b, int *nan, double *OUTPUT);

extern void endian_lowio_read_ieee_float64  (int fd, byte_order_t b, int *nan, double *OUTPUT);

extern void  endian_lowio_write_int1 (int, byte_order_t, const int);

extern void  endian_lowio_write_int2 (int, byte_order_t, const unsigned short);

extern void  endian_lowio_write_int4 (int, byte_order_t, const unsigned long);

extern void  endian_lowio_write_int8 (int, byte_order_t, const unsigned long long);

extern void  endian_lowio_write_ieee_float32 (int, byte_order_t, const float);

extern void  endian_lowio_write_ieee_float64 (int, byte_order_t, const double);

%}

